# Generated by Django 2.2.4 on 2020-03-09 13:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('listings', '0002_auto_20200309_1403'),
    ]

    operations = [
        migrations.RenameField(
            model_name='accommodation',
            old_name='bookings_enabled',
            new_name='booking_enabled',
        ),
        migrations.RenameField(
            model_name='accommodation',
            old_name='bookings_max_period',
            new_name='booking_max_period',
        ),
        migrations.RenameField(
            model_name='accommodation',
            old_name='bookings_min_period',
            new_name='booking_min_period',
        ),
        migrations.RenameField(
            model_name='accommodation',
            old_name='bookings_min_persons',
            new_name='booking_min_persons',
        ),
        migrations.RenameField(
            model_name='eatanddrink',
            old_name='bookings_enabled',
            new_name='booking_enabled',
        ),
        migrations.RenameField(
            model_name='eatanddrink',
            old_name='bookings_max_period',
            new_name='booking_max_period',
        ),
        migrations.RenameField(
            model_name='eatanddrink',
            old_name='bookings_min_period',
            new_name='booking_min_period',
        ),
        migrations.RenameField(
            model_name='eatanddrink',
            old_name='bookings_min_persons',
            new_name='booking_min_persons',
        ),
    ]
