# Generated by Django 2.2.4 on 2019-08-08 13:13

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('threadedcomments', '0003_threadedcomment_newest_activity'),
    ]

    operations = [
        migrations.CreateModel(
            name='ReviewComment',
            fields=[
                ('threadedcomment_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='threadedcomments.ThreadedComment')),
                ('type', models.CharField(choices=[('COMMENT', 'comment'), ('REVIEW', 'review')], max_length=7, verbose_name='type')),
                ('rating', models.PositiveSmallIntegerField(blank=True, default=None, null=True, validators=[django.core.validators.MinValueValidator(1), django.core.validators.MaxValueValidator(5)], verbose_name='rating')),
            ],
            options={
                'verbose_name': 'comment',
                'verbose_name_plural': 'comments',
                'ordering': ('submit_date',),
                'permissions': [('can_moderate', 'Can moderate comments')],
                'abstract': False,
            },
            bases=('threadedcomments.threadedcomment',),
        ),
    ]
